@@ -18,7 +18,7 @@ This file is part of rghk.
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with ZiK; if not, write to the Free Software
+    along with rghk; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 =end
 
@@ -33,4 +33,4 @@ have_header('gdk/gdkevents.h') or exit 1
 have_header('gdk/gdkx.h') or exit 1
 have_header('X11/Xlib.h') or exit 1
 
-create_makefile("rghk")
+create_makefile("globalhotkeys")
